/************************************************************************
*									*
*	DMX Dongle utility  V1.2  		  			*
*									*
*	(C) Copyright Artistic Licence (UK) Ltd 1995-96			*
*                                                                       *
*	NOT FOR DISTRIBUTION WITHOUT WRITTEN PERMISSION			*
*									*
*       Author W D Howell						*
*									*
*-----------------------------------------------------------------------*
*									*
*       ported to Linux by Michael Stickel (michael@cubic.org)		*
*									*
************************************************************************/

#ifndef DONGLE__H
#define DONGLE__H

#define version_major 1
#define version_minor 0

#define YES 1
#define NO 0

unsigned char init_dongle(unsigned int addr);
char end_dongle(void);
char tx_dmx(int memory);
char rx_dmx(void);
char rx_reset_counters(void);
char reset_rx_base(unsigned int base);
char is_error_flag(void);
void clr_memory(void);
void clr_rx(void);
unsigned char set_rx_header(unsigned char rheader);
unsigned char get_rx_header(void);
unsigned char set_tx_header(unsigned char theader);
unsigned char get_tx_header(void);
unsigned char set_tx_break_time(unsigned char break_time);
unsigned char get_tx_break_time(void);
unsigned char set_tx_mab_time(unsigned char mab_time);
unsigned char get_tx_mab_time(void);
unsigned char set_tx_aux1(unsigned char aux1);
unsigned char get_tx_aux1(void);
unsigned char set_compress(unsigned char compress);
unsigned char get_compress(void);
char wait_for_break(void);
unsigned int set_delay(unsigned int timer);
unsigned char get_firmware(void);
unsigned char get_dongle_type(void);


#define TIMEOUT 10000
/* timeout is set to a large value to allow smartdrive to pause
   the wait for ack cycle */



/* This is used to store processed data back from dongle */

typedef struct {
  unsigned int	channel_count;	/* number of rx chan 0-512 */
  unsigned int	period;		/* dmx cycle time in mS */
  unsigned int	cap1;
  unsigned int	cap2;
  unsigned int	brk; 		/* dmx break period in uS */
  unsigned int	mab;		/* mark after break in uS */
  unsigned int	frequency;	/* dmx update rate in Hz */
  unsigned int	break_count;	/* dmx frame counter */
  unsigned int	ovr_count;	/* overrun counter */
  unsigned int	hdr_count;      /* bad header counter */
  unsigned int	frm_count;      /* framing error counter */
} RX_CTRL;

#define	MAX_MEM		50	/* */
#define LEGEND_LENGTH	35
#define MAX_CHAN	512


typedef struct {
  unsigned char	level[MAX_CHAN];
  char		legend[LEGEND_LENGTH+1];
} MEM;


typedef struct {
  unsigned char	cur_level[MAX_CHAN];
  unsigned char	min_level[MAX_CHAN];
  unsigned char	max_level[MAX_CHAN];
} RX;

#endif
