/************************************************************************
*									*
*	DMX Dongle utility  V1.2  		  			*
*									*
*	(C) Copyright Artistic Licence (UK) Ltd 1995-96			*
*                                                                       *
*	NOT FOR DISTRIBUTION WITHOUT WRITTEN PERMISSION			*
*									*
*       Author W D Howell						*
*									*
*-----------------------------------------------------------------------*
*									*
*       ported to Linux by Michael Stickel (michael@cubic.org)		*
*									*
************************************************************************/

#include <curses.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/io.h>

#include "dongle.h"

extern RX rx;
extern RX_CTRL rx_ctrl;

void exit_app () 
{
  printf ("\nexit application\n");
  end_dongle ();
  ioperm (0x378, 8, 0);
  ioperm (0x278, 8, 0);
  ioperm (0x3bc, 3, 0);
  endwin ();
  exit (0);
}

int main(int argc, char **argv)
{
  int found=0;

  atexit(exit_app);

  if(argc>=2)
    found=strtol(argv[1], 0, 0);

  if(found>0 && found<0x10000)
    {
      if(iopl(3) < 0)
	{
	  perror("could get permisson for ioport");
	  return 1;
	}
      else
	{
	  if(init_dongle(found)!=0x05) 
	    {
	      printf("no DMX-Dongle found\n");
	      return 1;
	    }
	}
    }

  if(found==0)
    {
      ioperm (0x378, 8, 1);
      if (init_dongle(0x378) == 0x5) 
	found=1;
    }

  if(found==0)
    {
      ioperm (0x378, 8, 0);
      ioperm (0x278, 8, 1);
      if (init_dongle(0x278) == 0x5) 
	found=1;
    }

  if(found==0)
    {
      ioperm (0x278, 8, 0);
      ioperm (0x3BC, 8, 1);
      if (init_dongle(0x3BC) == 0x5) 
	found=1;
    }

  if(found)
    {
      int i, x, y, maxlines;

      WINDOW *w = initscr ();
      if (!w) return 1;

      maxlines=(LINES-2) & 0xFFFE; /* make maxlines even */

      set_compress (NO);

      attron(A_REVERSE);
      i=0;
      for(y=0; y<maxlines && i<512; y+=2)
	for(x=0; x<COLS-3 && i<512; x+=4)
	  mvwprintw(w, y, x, "%03d ", i++);
      attroff(A_REVERSE);
      
      while (1) 
	{
	  set_rx_header(0);
	  reset_rx_base(0);
	  
	  rx_dmx ();
	  
	  i=0;
	  for(y=1; y<=maxlines && i<512; y+=2)
	    for(x=1; x<COLS-2 && i<512; x+=4)
	      mvwprintw(w, y, x, "%02X", rx.cur_level[i++]);

	  mvwprintw(w, LINES-1, 0, "slots: %03i  period: %03i ms  break: %03i us  mab: %03i us  freq: %04i Hz  frame: %i",
		    rx_ctrl.channel_count, rx_ctrl.period, rx_ctrl.mab,
		    rx_ctrl.brk, rx_ctrl.frequency,
		    rx_ctrl.break_count);

	  wrefresh (w);
	}

    }

  printf ("no DMX-Dongle found\n");
  return 0;
}
